[vlc-commits] Bump libvlcpp version

2018-05-09 Thread Hugo Beauzée-Luyssen
npapi-vlc | branch: master | Hugo Beauzée-Luyssen  | Wed May  
9 20:46:14 2018 -0700| [c51e378f786e7fb3b96d6044a379356cf62c00fa] | committer: 
Hugo Beauzée-Luyssen

Bump libvlcpp version

> https://code.videolan.org/videolan/npapi-vlc/commit/c51e378f786e7fb3b96d6044a379356cf62c00fa
---

 vlcpp | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/vlcpp b/vlcpp
index 3088cfe..28e2c7a 16
--- a/vlcpp
+++ b/vlcpp
@@ -1 +1 @@
-Subproject commit 3088cfe51bbfda2c2ada51107aabf930938f9910
+Subproject commit 28e2c7a668e740471c80eb3e7d66162aeffee4cf

___
vlc-commits mailing list
vlc-commits@videolan.org
https://mailman.videolan.org/listinfo/vlc-commits


[vlc-commits] Update deinterlace functions to recent API changes

2018-05-09 Thread Hugo Beauzée-Luyssen
npapi-vlc | branch: master | Hugo Beauzée-Luyssen  | Wed May  
9 20:47:33 2018 -0700| [d64081f678a467a95fc0641f6967281a7098da36] | committer: 
Hugo Beauzée-Luyssen

Update deinterlace functions to recent API changes

> https://code.videolan.org/videolan/npapi-vlc/commit/d64081f678a467a95fc0641f6967281a7098da36
---

 activex/vlccontrol2.cpp   | 10 ++
 npapi/npruntime/npolibvlc.cpp |  9 +
 2 files changed, 19 insertions(+)

diff --git a/activex/vlccontrol2.cpp b/activex/vlccontrol2.cpp
index 2cd9530..9e7cfb1 100644
--- a/activex/vlccontrol2.cpp
+++ b/activex/vlccontrol2.cpp
@@ -562,7 +562,12 @@ STDMETHODIMP VLCAudio::toggleMute()
 
 STDMETHODIMP VLCDeinterlace::disable()
 {
+#if LIBVLC_VERSION_INT >= LIBVLC_VERSION(4, 0, 0, 0)
+_plug->get_player().get_mp().setDeinterlace( 
VLC::MediaPlayer::DeinterlaceState::Disabled,
+ std::string() );
+#else
 _plug->get_player().get_mp().setDeinterlace( "" );
+#endif
 return S_OK;
 }
 
@@ -571,7 +576,12 @@ STDMETHODIMP VLCDeinterlace::enable(BSTR mode)
 char *psz_mode = CStrFromBSTR(CP_UTF8, mode);
 if ( psz_mode == nullptr )
 return E_OUTOFMEMORY;
+#if LIBVLC_VERSION_INT >= LIBVLC_VERSION(4, 0, 0, 0)
+_plug->get_player().get_mp().setDeinterlace( 
VLC::MediaPlayer::DeinterlaceState::Enabled,
+ psz_mode );
+#else
 _plug->get_player().get_mp().setDeinterlace( psz_mode );
+#endif
 CoTaskMemFree(psz_mode);
 return S_OK;
 }
diff --git a/npapi/npruntime/npolibvlc.cpp b/npapi/npruntime/npolibvlc.cpp
index f096b4c..87230d5 100644
--- a/npapi/npruntime/npolibvlc.cpp
+++ b/npapi/npruntime/npolibvlc.cpp
@@ -1981,7 +1981,12 @@ LibvlcDeinterlaceNPObject::invoke(int index, const 
NPVariant *args,
 switch( index )
 {
 case ID_deint_disable:
+#if LIBVLC_VERSION_INT >= LIBVLC_VERSION(4, 0, 0, 0)
+mp.setDeinterlace( VLC::MediaPlayer::DeinterlaceState::Disabled,
+   std::string() );
+#else
 mp.setDeinterlace( std::string() );
+#endif
 break;
 
 case ID_deint_enable:
@@ -1992,7 +1997,11 @@ LibvlcDeinterlaceNPObject::invoke(int index, const 
NPVariant *args,
 if ( !v.is() )
 return INVOKERESULT_INVALID_VALUE;
 
+#if LIBVLC_VERSION_INT >= LIBVLC_VERSION(4, 0, 0, 0)
+mp.setDeinterlace( VLC::MediaPlayer::DeinterlaceState::Enabled, v );
+#else
 mp.setDeinterlace( v );
+#endif
 break;
 }
 default:

___
vlc-commits mailing list
vlc-commits@videolan.org
https://mailman.videolan.org/listinfo/vlc-commits


[vlc-commits] [Git][videolan/npapi-vlc][master] 2 commits: Bump libvlcpp version

2018-05-09 Thread Hugo Beauzée-Luyssen
Hugo Beauzée-Luyssen pushed to branch master at VideoLAN / VLC Browser Plugins


Commits:
c51e378f by Hugo Beauzée-Luyssen at 2018-05-09T20:48:26-07:00
Bump libvlcpp version

- - - - -
d64081f6 by Hugo Beauzée-Luyssen at 2018-05-09T20:48:26-07:00
Update deinterlace functions to recent API changes

- - - - -


3 changed files:

- activex/vlccontrol2.cpp
- npapi/npruntime/npolibvlc.cpp
- vlcpp


Changes:

=
activex/vlccontrol2.cpp
=
--- a/activex/vlccontrol2.cpp
+++ b/activex/vlccontrol2.cpp
@@ -562,7 +562,12 @@ STDMETHODIMP VLCAudio::toggleMute()
 
 STDMETHODIMP VLCDeinterlace::disable()
 {
+#if LIBVLC_VERSION_INT >= LIBVLC_VERSION(4, 0, 0, 0)
+_plug->get_player().get_mp().setDeinterlace( 
VLC::MediaPlayer::DeinterlaceState::Disabled,
+ std::string() );
+#else
 _plug->get_player().get_mp().setDeinterlace( "" );
+#endif
 return S_OK;
 }
 
@@ -571,7 +576,12 @@ STDMETHODIMP VLCDeinterlace::enable(BSTR mode)
 char *psz_mode = CStrFromBSTR(CP_UTF8, mode);
 if ( psz_mode == nullptr )
 return E_OUTOFMEMORY;
+#if LIBVLC_VERSION_INT >= LIBVLC_VERSION(4, 0, 0, 0)
+_plug->get_player().get_mp().setDeinterlace( 
VLC::MediaPlayer::DeinterlaceState::Enabled,
+ psz_mode );
+#else
 _plug->get_player().get_mp().setDeinterlace( psz_mode );
+#endif
 CoTaskMemFree(psz_mode);
 return S_OK;
 }


=
npapi/npruntime/npolibvlc.cpp
=
--- a/npapi/npruntime/npolibvlc.cpp
+++ b/npapi/npruntime/npolibvlc.cpp
@@ -1981,7 +1981,12 @@ LibvlcDeinterlaceNPObject::invoke(int index, const 
NPVariant *args,
 switch( index )
 {
 case ID_deint_disable:
+#if LIBVLC_VERSION_INT >= LIBVLC_VERSION(4, 0, 0, 0)
+mp.setDeinterlace( VLC::MediaPlayer::DeinterlaceState::Disabled,
+   std::string() );
+#else
 mp.setDeinterlace( std::string() );
+#endif
 break;
 
 case ID_deint_enable:
@@ -1992,7 +1997,11 @@ LibvlcDeinterlaceNPObject::invoke(int index, const 
NPVariant *args,
 if ( !v.is() )
 return INVOKERESULT_INVALID_VALUE;
 
+#if LIBVLC_VERSION_INT >= LIBVLC_VERSION(4, 0, 0, 0)
+mp.setDeinterlace( VLC::MediaPlayer::DeinterlaceState::Enabled, v );
+#else
 mp.setDeinterlace( v );
+#endif
 break;
 }
 default:


=
vlcpp
=
--- a/vlcpp
+++ b/vlcpp
@@ -1 +1 @@
-Subproject commit 3088cfe51bbfda2c2ada51107aabf930938f9910
+Subproject commit 28e2c7a668e740471c80eb3e7d66162aeffee4cf



View it on GitLab: 
https://code.videolan.org/videolan/npapi-vlc/compare/4cde6f00728526999b67786e5f8fb2e57fda2298...d64081f678a467a95fc0641f6967281a7098da36

---
View it on GitLab: 
https://code.videolan.org/videolan/npapi-vlc/compare/4cde6f00728526999b67786e5f8fb2e57fda2298...d64081f678a467a95fc0641f6967281a7098da36
You're receiving this email because of your account on code.videolan.org.
___
vlc-commits mailing list
vlc-commits@videolan.org
https://mailman.videolan.org/listinfo/vlc-commits


[vlc-commits] [Git][videolan/libvlcpp][master] MediaPlayer: Update to recent set_deinterlace changes

2018-05-09 Thread Hugo Beauzée-Luyssen
Hugo Beauzée-Luyssen pushed to branch master at VideoLAN / libvlcpp


Commits:
28e2c7a6 by Hugo Beauzée-Luyssen at 2018-05-09T20:44:56-07:00
MediaPlayer: Update to recent set_deinterlace changes

- - - - -


1 changed file:

- vlcpp/MediaPlayer.hpp


Changes:

=
vlcpp/MediaPlayer.hpp
=
diff --git a/share/vlc.desktop.in b/share/vlc.desktop.in
index 69c00af25e..0f49d6e344 100644
--- a/share/vlc.desktop.in
+++ b/share/vlc.desktop.in
@@ -3,6 +3,15 @@ Version=1.0
 Name=VLC media player
 GenericName=Media player
 Comment=Read, capture, broadcast your multimedia streams
+Name[am_ET]=የ ቪኤልሲ መገናኛ ማጫወቻ 
+GenericName[am_ET]=የ መገናኛ ማጫወቻ
+Comment[am_ET]=የ እርስዎን በርካታ መገናኛ ማንበቢያ: መያዣ ማስተላለፊያ
+Name[ar]=مشغل الوسائط VLC
+GenericName[ar]=مشغل الوسائط
+Comment[ar]=اقرأ ، التقط ، و بث تدفقات وسائطك المتعددة
+Name[bg]=Медиен плейър VLC
+GenericName[bg]=Медиен плейър
+Comment[bg]=Прочитане, прихващане и излъчване на мултимедийни потоци.
 Name[bn]=VLC মিডিয়া প্লেয়ার
 Comment[bn]=আপনার মাল্টিমিডিয়া স্ট্রীম পড়ুন, ধরে রাখুন এবং ছড়িয়ে দিন
 Name[br]=VLC lenner mediaoù
@@ -31,32 +40,36 @@ GenericName[fi]=Mediasoitin
 Comment[fi]=Toista, tallenna ja lähetä multimediaa
 Name[fr]=Lecteur multimédia VLC
 GenericName[fr]=Lecteur multimédia
-Comment[fr]=Lire, capturer, diffuser vos flux multimedia
+Comment[fr]=Lit, capture, diffuse vos flux multimédia
 Name[gl]=Reprodutor multimedia VLC
 GenericName[gl]=Reprodutor multimedia
 Comment[gl]=Lea, capture e emita os seus fluxos multimedia
 Name[he]=נגן המדיה VLC
 GenericName[he]=נגן מדיה
-Comment[he]=קריאה, לכידה ושידור של תזרימי מולטימדיה
+Comment[he]=קריאה, לכידה ושידור של תזרימי המולטימדיה שלך
 Name[hu]=VLC médialejátszó
 GenericName[hu]=Médialejátszó
-Comment[hu]=Multimédiás adatfolyamok olvasása, mentése, szórása
-Name[is]=VLC margmiðlunarspilarinn
+Comment[hu]=Multimédia adatfolyamok olvasása, felvétele és továbbítása
+Name[is]=VLC spilarinn
 GenericName[is]=Margmiðlunarspilari
-Comment[is]=Spilar margmiðlunarefni ásamt því að taka upp og útvarpa straumum
+Comment[is]=Lesa, taka upp og útvarpa margmiðlunarstreymi
 Name[it]=Lettore multimediale VLC
 GenericName[it]=Lettore multimediale
-Comment[it]=Legge, acquisisce e trasmette i tuoi flussi multimediali
+Comment[it]=Leggi, cattura, trasmetti i tuoi flussi multimediali
 Name[ja]=VLCメディアプレイヤー
+GenericName[ja]=メディアプレイヤー
 Comment[ja]=マルチメディアストリームの読み込み、キャプチャー、ブロードキャスト
 Name[km]=កម្មវិធី​ចាក់​មេឌៀ VLC
 Comment[km]=អាន ចាប់យក ប្រកាស​ស្ទ្រីម​ពហុមេឌៀ​របស់​អ្នក
 Name[lt]=VLC leistuvė 
 GenericName[lt]=Leistuvė
 Comment[lt]=Groti, įrašyti, siųsti įvairialypės terpės kūrinius
+Name[ms]=Pemain media VLC
+GenericName[ms]=Pemain media
+Comment[ms]=Baca, tangkap, siarkan strim multimedia anda
 Name[nl]=VLC Media Player
 GenericName[nl]=Mediaspeler
-Comment[nl]=Uw multimediastreams afspelen, opnemen en uitzenden
+Comment[nl]=Uw multimedia-streams lezen, opnemen en uitzenden
 Name[nn]=VLC mediespelar
 GenericName[nn]=Mediespelar
 Comment[nn]=Spel av, ta opp og send ut multimedia
@@ -68,23 +81,39 @@ Comment[pl]=Odczytywanie, przechwytywanie i nadawanie 
strumieni multimedialnych
 Name[pt_BR]=Reprodutor de Mídias VLC
 GenericName[pt_BR]=Reprodutor de Mídias
 Comment[pt_BR]=Reproduza, capture e transmita os seus fluxos multimídia
+Name[pt_PT]=VLC media player
+GenericName[pt_PT]=Reprodutor de Multimédia
+Comment[pt_PT]=Ler, capturar, transmitir as suas emissões de multimédia
+Name[ro]=Redor media VLC
+GenericName[ro]=Redor media
+Comment[ro]=Citește, capturează, difuzează fluxurile multimedia
 Name[ru]=Медиаплеер VLC
 GenericName[ru]=Медиаплеер
 Comment[ru]=Универсальный проигрыватель видео и аудио
 Name[sk]=VLC media player
-Comment[sk]=Naèítavajte, zaznamenávajte, vysielajte svoje multimediálne streamy
+GenericName[sk]=Prehrávač médií
+Comment[sk]=Načítavajte, zaznamenávajte, vysielajte svoje multimediálne streamy
 Name[sv]=VLC mediaspelare
 GenericName[sv]=Mediaspelare
-Comment[sv]=Spelare för film och musik
+Comment[sv]=Läs, fånga, sänd dina multimediaströmmar
 Name[te]=VLC మాధ్యమ ప్రదర్శకం
 GenericName[te]=మాధ్యమ ప్రదర్శకం
 Comment[te]=మీ బహుళమాధ్యమ ప్రవాహాలను చదువు, బంధించు మరియు ప్రసారం చేయి
+Name[th]=โปรแกรมเล่นสื่อ VLC 
+GenericName[th]=โปรแกรมเล่นสื่อ
+Comment[th]=อ่าน จับ และถ่ายทอดสตรีมมัลติมีเดียของคุณ
+Name[tr]=VLC ortam oynatıcısı
+GenericName[tr]=Ortam oynatıcısı
+Comment[tr]=Çoklu ortam akışlarınızı okuyun, yakalayın, yayınlayın
+Name[uk]=Медіапрогравач VLC
+GenericName[uk]=Медіапрогравач
+Comment[uk]=Читання, захоплення та поширення ваших мультимедійних потоків
 Name[wa]=Djouweu d' media VLC
 GenericName[wa]=Djouweu d' media
 Comment[wa]=Lét, egaloye, evoye vos floûs multimedia
-Name[zh_CN]=VLC media player
+Name[zh_CN]=VLC 媒体播放器
 GenericName[zh_CN]=媒体播放器
-Comment[zh_CN]=为您读取、捕获或发送多媒体流
+Comment[zh_CN]=读取、捕获、广播您的多媒体流
 Exec=@bindir@/vlc 

[vlc-commits] Update PO files

2018-05-09 Thread Jean-Baptiste Kempf
vlc/vlc-3.0 | branch: master | Jean-Baptiste Kempf  | Wed 
May  9 23:44:40 2018 +0200| [fb3a5ca94213acbad8a995d240f3f3ff78dd71b2] | 
committer: Jean-Baptiste Kempf

Update PO files

> http://git.videolan.org/gitweb.cgi/vlc/vlc-3.0.git/?a=commit;h=fb3a5ca94213acbad8a995d240f3f3ff78dd71b2
---

 po/ach.po   | 265 +--
 po/af.po| 265 +--
 po/am.po| 265 +--
 po/an.po| 265 +--
 po/ar.po| 265 +--
 po/as_IN.po | 265 +--
 po/ast.po   | 265 +--
 po/az.po| 265 +--
 po/be.po| 265 +--
 po/bg.po| 265 +--
 po/bn.po| 265 +--
 po/bn_IN.po | 265 +--
 po/br.po| 265 +--
 po/brx.po   | 265 +--
 po/bs.po| 265 +--
 po/ca.po| 265 +--
 po/cgg.po   | 265 +--
 po/ckb.po   | 265 +--
 po/co.po| 265 +--
 po/cs.po| 265 +--
 po/cy.po| 265 +--
 po/da.po| 265 +--
 po/de.po| 265 +--
 po/el.po| 265 +--
 po/en_GB.po | 265 +--
 po/es.po| 265 +--
 po/et.po| 265 +--
 po/eu.po| 265 +--
 po/fa.po| 265 +--
 po/ff.po| 265 +--
 po/fi.po| 265 +--
 po/fr.po| 265 +--
 po/fur.po   | 265 +--
 po/fy.po| 265 +--
 po/ga.po| 265 +--
 po/gd.po| 265 +--
 po/gl.po| 265 +--
 po/gu.po| 265 +--
 po/he.po| 265 +--
 po/hi.po| 265 +--
 po/hr.po| 265 +--
 po/hu.po| 265 +--
 po/hy.po| 265 +--
 po/ia.po| 265 +--
 po/id.po| 265 +--
 po/is.po| 265 +--
 po/it.po| 265 +--
 po/ja.po| 265 +--
 po/ka.po| 265 +--
 po/kk.po| 265 +--
 po/km.po| 265 +--
 po/kn.po| 265 +--
 po/ko.po| 265 +--
 po/ks_IN.po | 265 +--
 po/ky.po| 265 +--
 po/lg.po| 265 +--
 po/lt.po| 265 +--
 po/lv.po| 265 +--
 po/mai.po   | 265 +--
 po/mk.po| 265 

[vlc-commits] macosx: Choose existing string for hardware decoding option

2018-05-09 Thread David Fuhrmann
vlc/vlc-3.0 | branch: master | David Fuhrmann  | Wed 
May  9 20:12:22 2018 +0200| [ff9edbff260c85011f3f5e7177744a35a5b640d2] | 
committer: David Fuhrmann

macosx: Choose existing string for hardware decoding option

This string is already translated.

> http://git.videolan.org/gitweb.cgi/vlc/vlc-3.0.git/?a=commit;h=ff9edbff260c85011f3f5e7177744a35a5b640d2
---

 modules/gui/macosx/VLCSimplePrefsController.m | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/modules/gui/macosx/VLCSimplePrefsController.m 
b/modules/gui/macosx/VLCSimplePrefsController.m
index a876d9b356..f9b0798037 100644
--- a/modules/gui/macosx/VLCSimplePrefsController.m
+++ b/modules/gui/macosx/VLCSimplePrefsController.m
@@ -294,7 +294,7 @@ create_toolbar_item(NSString *itemIdent, NSString *name, 
NSString *desc, NSStrin
 [_input_cachelevel_customLabel setStringValue: _NS("Use the complete 
preferences to configure custom caching values for each access module.")];
 [_input_muxBox setTitle: _NS("Codecs / Muxers")];
 [_input_netBox setTitle: _NS("Network")];
-[_input_hardwareAccelerationCheckbox setTitle: _NS("Enable hardware 
acceleration")];
+[_input_hardwareAccelerationCheckbox setTitle: _NS("Hardware decoding")];
 [_input_postprocLabel setStringValue: _NS("Post-Processing Quality")];
 [_input_skipLoopLabel setStringValue: _NS("Skip the loop filter for H.264 
decoding")];
 [_input_urlhandlerButton setTitle: _NS("Edit default application settings 
for network protocols")];

___
vlc-commits mailing list
vlc-commits@videolan.org
https://mailman.videolan.org/listinfo/vlc-commits


[vlc-commits] lib: remove unused libvlc_playlist_play() parameters

2018-05-09 Thread Rémi Denis-Courmont
vlc | branch: master | Rémi Denis-Courmont  | Wed May  9 
12:53:32 2018 +0300| [1d233ef6be603b03d67cb45d27bb8c0391f866df] | committer: 
Rémi Denis-Courmont

lib: remove unused libvlc_playlist_play() parameters

> http://git.videolan.org/gitweb.cgi/vlc.git/?a=commit;h=1d233ef6be603b03d67cb45d27bb8c0391f866df
---

 bin/darwinvlc.m  | 2 +-
 bin/vlc.c| 2 +-
 bin/winvlc.c | 2 +-
 include/vlc/deprecated.h | 8 +---
 lib/playlist.c   | 4 +---
 5 files changed, 5 insertions(+), 13 deletions(-)

diff --git a/bin/darwinvlc.m b/bin/darwinvlc.m
index df4c52c7f4..3ba5c6547b 100644
--- a/bin/darwinvlc.m
+++ b/bin/darwinvlc.m
@@ -292,7 +292,7 @@ int main(int i_argc, const char *ppsz_argv[])
 fprintf(stderr, "VLC cannot start any interface. Exiting.\n");
 goto out;
 }
-libvlc_playlist_play(vlc, -1, 0, NULL);
+libvlc_playlist_play(vlc);
 
 /*
  * Run the main loop. If the mac interface is not initialized, only the 
CoreFoundation
diff --git a/bin/vlc.c b/bin/vlc.c
index f06cc30abd..660a1b7996 100644
--- a/bin/vlc.c
+++ b/bin/vlc.c
@@ -246,7 +246,7 @@ int main(int argc, const char *argv[])
 goto out;
 }
 
-libvlc_playlist_play (vlc, -1, 0, NULL);
+libvlc_playlist_play (vlc);
 
 /* Qt insists on catching SIGCHLD via signal handler. To work around that,
  * unblock it after all our child threads are created. */
diff --git a/bin/winvlc.c b/bin/winvlc.c
index 8f22946fef..e55f043a8b 100644
--- a/bin/winvlc.c
+++ b/bin/winvlc.c
@@ -246,7 +246,7 @@ int WINAPI WinMain( HINSTANCE hInstance, HINSTANCE 
hPrevInstance,
 libvlc_add_intf (vlc, "hotkeys,none");
 libvlc_add_intf (vlc, "globalhotkeys,none");
 libvlc_add_intf (vlc, NULL);
-libvlc_playlist_play (vlc, -1, 0, NULL);
+libvlc_playlist_play (vlc);
 libvlc_wait (vlc);
 libvlc_release (vlc);
 }
diff --git a/include/vlc/deprecated.h b/include/vlc/deprecated.h
index 735f98151e..6eecd15ec2 100644
--- a/include/vlc/deprecated.h
+++ b/include/vlc/deprecated.h
@@ -189,15 +189,9 @@ void libvlc_wait( libvlc_instance_t *p_instance );
  * item before it is played.
  *
  * \param p_instance the playlist instance
- * \param i_id the item to play. If this is a negative number, the next
- *item will be selected. Otherwise, the item with the given ID will be
- *played
- * \param i_options the number of options to add to the item
- * \param ppsz_options the options to add to the item
  */
 LIBVLC_DEPRECATED LIBVLC_API
-void libvlc_playlist_play( libvlc_instance_t *p_instance, int i_id,
-   int i_options, char **ppsz_options );
+void libvlc_playlist_play( libvlc_instance_t *p_instance );
 
 /** @}*/
 
diff --git a/lib/playlist.c b/lib/playlist.c
index 2aa6e1c705..acb4c15f73 100644
--- a/lib/playlist.c
+++ b/lib/playlist.c
@@ -34,11 +34,9 @@
 
 #include 
 
-void libvlc_playlist_play( libvlc_instance_t *p_instance, int i_id,
-   int i_options, char **ppsz_options )
+void libvlc_playlist_play( libvlc_instance_t *p_instance )
 {
 libvlc_InternalPlay( p_instance->p_libvlc_int );
-VLC_UNUSED(i_id); VLC_UNUSED(i_options); VLC_UNUSED(ppsz_options);
 }
 
 int libvlc_add_intf( libvlc_instance_t *p_instance, const char *name )

___
vlc-commits mailing list
vlc-commits@videolan.org
https://mailman.videolan.org/listinfo/vlc-commits


[vlc-commits] modules: do not use 0 for NULL

2018-05-09 Thread Rémi Denis-Courmont
vlc | branch: master | Rémi Denis-Courmont  | Wed May  9 
20:54:28 2018 +0300| [f67e6764d98a6ae0c5470fd7db078929e9e0f2a0] | committer: 
Rémi Denis-Courmont

modules: do not use 0 for NULL

> http://git.videolan.org/gitweb.cgi/vlc.git/?a=commit;h=f67e6764d98a6ae0c5470fd7db078929e9e0f2a0
---

 src/modules/cache.c | 12 ++--
 1 file changed, 6 insertions(+), 6 deletions(-)

diff --git a/src/modules/cache.c b/src/modules/cache.c
index 53c577c1a4..ccd9ffccae 100644
--- a/src/modules/cache.c
+++ b/src/modules/cache.c
@@ -374,7 +374,7 @@ vlc_plugin_t *vlc_cache_load(vlc_object_t *p_this, const 
char *dir,
 assert( dir != NULL );
 
 if( asprintf( _filename, "%s"DIR_SEP CACHE_NAME, dir ) == -1 )
-return 0;
+return NULL;
 
 msg_Dbg( p_this, "loading plugins cache file %s", psz_filename );
 
@@ -384,7 +384,7 @@ vlc_plugin_t *vlc_cache_load(vlc_object_t *p_this, const 
char *dir,
  vlc_strerror_c(errno));
 free(psz_filename);
 if (file == NULL)
-return 0;
+return NULL;
 
 /* Check the file is a plugins cache */
 char cachestr[sizeof (CACHE_STRING) - 1];
@@ -394,7 +394,7 @@ vlc_plugin_t *vlc_cache_load(vlc_object_t *p_this, const 
char *dir,
 {
 msg_Warn( p_this, "This doesn't look like a valid plugins cache" );
 block_Release(file);
-return 0;
+return NULL;
 }
 
 #ifdef DISTRO_VERSION
@@ -406,7 +406,7 @@ vlc_plugin_t *vlc_cache_load(vlc_object_t *p_this, const 
char *dir,
 {
 msg_Warn( p_this, "This doesn't look like a valid plugins cache" );
 block_Release(file);
-return 0;
+return NULL;
 }
 #endif
 
@@ -419,7 +419,7 @@ vlc_plugin_t *vlc_cache_load(vlc_object_t *p_this, const 
char *dir,
 msg_Warn( p_this, "This doesn't look like a valid plugins cache "
   "(corrupted header)" );
 block_Release(file);
-return 0;
+return NULL;
 }
 
 /* Check header marker */
@@ -434,7 +434,7 @@ vlc_plugin_t *vlc_cache_load(vlc_object_t *p_this, const 
char *dir,
 msg_Warn( p_this, "This doesn't look like a valid plugins cache "
   "(corrupted header)" );
 block_Release(file);
-return 0;
+return NULL;
 }
 
 vlc_plugin_t *cache = NULL;

___
vlc-commits mailing list
vlc-commits@videolan.org
https://mailman.videolan.org/listinfo/vlc-commits


[vlc-commits] cachegen: remove wrong/misleading error message

2018-05-09 Thread Rémi Denis-Courmont
vlc | branch: master | Rémi Denis-Courmont  | Wed May  9 
20:36:07 2018 +0300| [31f34113ae22f3d6e803aa8ea9f77150c9b0154f] | committer: 
Rémi Denis-Courmont

cachegen: remove wrong/misleading error message

> http://git.videolan.org/gitweb.cgi/vlc.git/?a=commit;h=31f34113ae22f3d6e803aa8ea9f77150c9b0154f
---

 bin/cachegen.c | 5 +
 1 file changed, 1 insertion(+), 4 deletions(-)

diff --git a/bin/cachegen.c b/bin/cachegen.c
index 1a5a87f95c..5f0a1ac04b 100644
--- a/bin/cachegen.c
+++ b/bin/cachegen.c
@@ -88,12 +88,9 @@ int main (int argc, char *argv[])
 vlc_argv[vlc_argc] = NULL;
 
 libvlc_instance_t *vlc = libvlc_new (vlc_argc, vlc_argv);
-if (vlc != NULL)
-libvlc_release (vlc);
-if (vlc == NULL)
-fprintf (stderr, "No plugins in %s\n", path);
 if (vlc == NULL)
 return 1;
+libvlc_release(vlc);
 }
 
 return 0;

___
vlc-commits mailing list
vlc-commits@videolan.org
https://mailman.videolan.org/listinfo/vlc-commits


[vlc-commits] Update NEWS to mention macOS changes

2018-05-09 Thread David Fuhrmann
vlc/vlc-3.0 | branch: master | David Fuhrmann  | Wed 
May  9 20:04:13 2018 +0200| [92160d5984466f29c7ff4678a4a85830311274bd] | 
committer: David Fuhrmann

Update NEWS to mention macOS changes

> http://git.videolan.org/gitweb.cgi/vlc/vlc-3.0.git/?a=commit;h=92160d5984466f29c7ff4678a4a85830311274bd
---

 NEWS | 2 ++
 1 file changed, 2 insertions(+)

diff --git a/NEWS b/NEWS
index dad96e6933..32be96c84a 100644
--- a/NEWS
+++ b/NEWS
@@ -16,6 +16,8 @@ Demux:
 
 macOS:
  * Fix "Open Network Stream" URL box focus
+ * Add option to disable hardware acceleration for video decoding
+ * Remove option to force dolby mode from simple preferences
 
 Qt:
  * Fix tooltip display on some desktop environments

___
vlc-commits mailing list
vlc-commits@videolan.org
https://mailman.videolan.org/listinfo/vlc-commits


[vlc-commits] macosx: Remove force-dolby option from simple preferences

2018-05-09 Thread David Fuhrmann
vlc/vlc-3.0 | branch: master | David Fuhrmann  | Sat 
Mar 10 14:27:57 2018 +0100| [73b3bbd0b0ce40091221f46ec64555ed440863c8] | 
committer: David Fuhrmann

macosx: Remove force-dolby option from simple preferences

This option is outdated and does not work anymore.

(cherry picked from commit 244ee18790a24667c5cfcd2f5794e66f26c84810)
Signed-off-by: David Fuhrmann 

> http://git.videolan.org/gitweb.cgi/vlc/vlc-3.0.git/?a=commit;h=73b3bbd0b0ce40091221f46ec64555ed440863c8
---

 modules/gui/macosx/UI/SimplePreferences.xib   | 78 ---
 modules/gui/macosx/VLCSimplePrefsController.h |  2 -
 modules/gui/macosx/VLCSimplePrefsController.m |  4 --
 3 files changed, 22 insertions(+), 62 deletions(-)

Diff:   
http://git.videolan.org/gitweb.cgi/vlc/vlc-3.0.git/?a=commitdiff;h=73b3bbd0b0ce40091221f46ec64555ed440863c8
___
vlc-commits mailing list
vlc-commits@videolan.org
https://mailman.videolan.org/listinfo/vlc-commits


[vlc-commits] macosx: Add option to disable hardware accel. to simple preference

2018-05-09 Thread David Fuhrmann
vlc/vlc-3.0 | branch: master | David Fuhrmann  | Wed 
May  9 18:47:00 2018 +0200| [87405256c7682a595f05340f160dc23df31a598f] | 
committer: David Fuhrmann

macosx: Add option to disable hardware accel. to simple preference

Add option to simple prefs for enabling or disabling the videotoolbox
hardware acceleration decoder.

(cherry picked from commit 79871d5ba02fdab121fc7f5d721f1aa0ee233133)
Signed-off-by: David Fuhrmann 

> http://git.videolan.org/gitweb.cgi/vlc/vlc-3.0.git/?a=commit;h=87405256c7682a595f05340f160dc23df31a598f
---

 modules/gui/macosx/UI/SimplePreferences.xib   | 35 +++
 modules/gui/macosx/VLCSimplePrefsController.h |  1 +
 modules/gui/macosx/VLCSimplePrefsController.m |  5 
 3 files changed, 31 insertions(+), 10 deletions(-)

Diff:   
http://git.videolan.org/gitweb.cgi/vlc/vlc-3.0.git/?a=commitdiff;h=87405256c7682a595f05340f160dc23df31a598f
___
vlc-commits mailing list
vlc-commits@videolan.org
https://mailman.videolan.org/listinfo/vlc-commits


[vlc-commits] macosx: Add option to disable hardware accel. to simple preference

2018-05-09 Thread David Fuhrmann
vlc | branch: master | David Fuhrmann  | Wed May  9 
18:47:00 2018 +0200| [79871d5ba02fdab121fc7f5d721f1aa0ee233133] | committer: 
David Fuhrmann

macosx: Add option to disable hardware accel. to simple preference

Add option to simple prefs for enabling or disabling the videotoolbox
hardware acceleration decoder.

> http://git.videolan.org/gitweb.cgi/vlc.git/?a=commit;h=79871d5ba02fdab121fc7f5d721f1aa0ee233133
---

 modules/gui/macosx/UI/SimplePreferences.xib   | 35 +++
 modules/gui/macosx/VLCSimplePrefsController.h |  1 +
 modules/gui/macosx/VLCSimplePrefsController.m |  5 
 3 files changed, 31 insertions(+), 10 deletions(-)

diff --git a/modules/gui/macosx/UI/SimplePreferences.xib 
b/modules/gui/macosx/UI/SimplePreferences.xib
index 036ed61910..9723f8ae6d 100644
--- a/modules/gui/macosx/UI/SimplePreferences.xib
+++ b/modules/gui/macosx/UI/SimplePreferences.xib
@@ -1,5 +1,5 @@
 
-
+
 
 
 
@@ -48,6 +48,7 @@
 
 
 
+
 
 
 
@@ -1294,10 +1295,10 @@ Gw
 
 
 
-
+
 
 
-
+
 
 
 
@@ -1341,7 +1342,7 @@ Gw
 
 
 
-
+
 
 
 
@@ -1368,7 +1369,7 @@ Gw
 
 
 
-
+
 
 
 
@@ -1425,9 +1426,9 @@ Gw
 
 
 
-
+
 
-
+
 
 
 
@@ -1525,6 +1526,16 @@ Gw
 
 
 
+
+
+
+
+
+
+
+
+
+
 
 
 
@@ -1532,22 +1543,26 @@ Gw
 
 
 
+
 
 
 
 
 
+
+
 
 
-
+
+
 
 
-
 
 
 
 
 
+
 
 
 
@@ -2058,7 +2073,7 @@ Gw
 
 
 
-
+
 
 
 
diff --git a/modules/gui/macosx/VLCSimplePrefsController.h 
b/modules/gui/macosx/VLCSimplePrefsController.h
index 926feddeb5..ba4c5db670 100644
--- a/modules/gui/macosx/VLCSimplePrefsController.h
+++ b/modules/gui/macosx/VLCSimplePrefsController.h
@@ -85,6 +85,7 @@
 @property (readwrite, weak) IBOutlet NSBox *input_cachingBox;
 @property (readwrite, weak) IBOutlet NSBox *input_muxBox;
 @property (readwrite, weak) IBOutlet NSBox *input_netBox;
+@property (readwrite, weak) IBOutlet NSButton 
*input_hardwareAccelerationCheckbox;
 @property (readwrite, weak) IBOutlet NSTextField *input_postprocTextField;
 @property (readwrite, weak) IBOutlet NSTextField *input_postprocLabel;
 @property (readwrite, weak) IBOutlet NSTextField *input_skipLoopLabel;
diff --git a/modules/gui/macosx/VLCSimplePrefsController.m 
b/modules/gui/macosx/VLCSimplePrefsController.m
index bfd7183f83..feae10dabf 100644
--- a/modules/gui/macosx/VLCSimplePrefsController.m
+++ b/modules/gui/macosx/VLCSimplePrefsController.m
@@ -294,6 +294,7 @@ create_toolbar_item(NSString *itemIdent, NSString *name, 
NSString *desc, NSStrin
 [_input_cachelevel_customLabel setStringValue: _NS("Use the complete 
preferences to configure custom caching values for each access module.")];
 [_input_muxBox setTitle: _NS("Codecs / Muxers")];
 

[vlc-commits] vout: android: fix possible buffer underwrite with spus

2018-05-09 Thread Thomas Guillem
vlc/vlc-3.0 | branch: master | Thomas Guillem  | Wed May  9 
17:27:03 2018 +0200| [07a9566cbaf16124f9ac7b53cb48415cb3502e37] | committer: 
Thomas Guillem

vout: android: fix possible buffer underwrite with spus

(cherry picked from commit 4ef28fc0df5419d3dc59b6d91fe9498ce1a1d900)
Signed-off-by: Thomas Guillem 

> http://git.videolan.org/gitweb.cgi/vlc/vlc-3.0.git/?a=commit;h=07a9566cbaf16124f9ac7b53cb48415cb3502e37
---

 modules/video_output/android/display.c | 4 
 1 file changed, 4 insertions(+)

diff --git a/modules/video_output/android/display.c 
b/modules/video_output/android/display.c
index 2f6b8178d1..90b428be14 100644
--- a/modules/video_output/android/display.c
+++ b/modules/video_output/android/display.c
@@ -976,6 +976,10 @@ static void SubtitleRegionToBounds(subpicture_t 
*subpicture,
 
 new_bounds.left = r->i_x;
 new_bounds.top = r->i_y;
+if (new_bounds.left < 0)
+new_bounds.left = 0;
+if (new_bounds.top < 0)
+new_bounds.top = 0;
 new_bounds.right = r->fmt.i_visible_width + r->i_x;
 new_bounds.bottom = r->fmt.i_visible_height + r->i_y;
 if (r == >p_region[0])

___
vlc-commits mailing list
vlc-commits@videolan.org
https://mailman.videolan.org/listinfo/vlc-commits


[vlc-commits] vout: android: fix possible buffer underwrite with spus

2018-05-09 Thread Thomas Guillem
vlc | branch: master | Thomas Guillem  | Wed May  9 17:27:03 
2018 +0200| [4ef28fc0df5419d3dc59b6d91fe9498ce1a1d900] | committer: Thomas 
Guillem

vout: android: fix possible buffer underwrite with spus

> http://git.videolan.org/gitweb.cgi/vlc.git/?a=commit;h=4ef28fc0df5419d3dc59b6d91fe9498ce1a1d900
---

 modules/video_output/android/display.c | 4 
 1 file changed, 4 insertions(+)

diff --git a/modules/video_output/android/display.c 
b/modules/video_output/android/display.c
index e779f9e939..97ebf5d479 100644
--- a/modules/video_output/android/display.c
+++ b/modules/video_output/android/display.c
@@ -823,6 +823,10 @@ static void SubtitleRegionToBounds(subpicture_t 
*subpicture,
 
 new_bounds.left = r->i_x;
 new_bounds.top = r->i_y;
+if (new_bounds.left < 0)
+new_bounds.left = 0;
+if (new_bounds.top < 0)
+new_bounds.top = 0;
 new_bounds.right = r->fmt.i_visible_width + r->i_x;
 new_bounds.bottom = r->fmt.i_visible_height + r->i_y;
 if (r == >p_region[0])

___
vlc-commits mailing list
vlc-commits@videolan.org
https://mailman.videolan.org/listinfo/vlc-commits


[vlc-commits] libvlc: simplify set_deinterlace

2018-05-09 Thread Thomas Guillem
vlc | branch: master | Thomas Guillem  | Wed May  9 09:37:35 
2018 +0200| [511cdf1f691657f37a3c76f7770e690d06b157bd] | committer: Thomas 
Guillem

libvlc: simplify set_deinterlace

> http://git.videolan.org/gitweb.cgi/vlc.git/?a=commit;h=511cdf1f691657f37a3c76f7770e690d06b157bd
---

 lib/video.c | 9 +++--
 1 file changed, 3 insertions(+), 6 deletions(-)

diff --git a/lib/video.c b/lib/video.c
index 53b5de49db..3071b14157 100644
--- a/lib/video.c
+++ b/lib/video.c
@@ -600,10 +600,7 @@ void libvlc_video_set_deinterlace( libvlc_media_player_t 
*p_mi, int deinterlace,
 if (deinterlace != 0 && deinterlace != 1)
 deinterlace = -1;
 
-if (psz_mode == NULL)
-psz_mode = "";
-
-if (*psz_mode
+if (psz_mode
  && strcmp (psz_mode, "blend")&& strcmp (psz_mode, "bob")
  && strcmp (psz_mode, "discard")  && strcmp (psz_mode, "linear")
  && strcmp (psz_mode, "mean") && strcmp (psz_mode, "x")
@@ -612,7 +609,7 @@ void libvlc_video_set_deinterlace( libvlc_media_player_t 
*p_mi, int deinterlace,
  && strcmp (psz_mode, "auto"))
 return;
 
-if (*psz_mode && deinterlace != 0)
+if (psz_mode && deinterlace != 0)
 var_SetString (p_mi, "deinterlace-mode", psz_mode);
 
 var_SetInteger (p_mi, "deinterlace", deinterlace);
@@ -623,7 +620,7 @@ void libvlc_video_set_deinterlace( libvlc_media_player_t 
*p_mi, int deinterlace,
 {
 vout_thread_t *p_vout = pp_vouts[i];
 
-if (*psz_mode && deinterlace != 0)
+if (psz_mode && deinterlace != 0)
 var_SetString (p_vout, "deinterlace-mode", psz_mode);
 
 var_SetInteger (p_vout, "deinterlace", deinterlace);

___
vlc-commits mailing list
vlc-commits@videolan.org
https://mailman.videolan.org/listinfo/vlc-commits


[vlc-commits] libvlc: add "auto" deinterlace-mode

2018-05-09 Thread Luis Fernandes
vlc | branch: master | Luis Fernandes  | Mon Apr 30 14:33:08 
2018 +0100| [174840ba85945431cfe55955671508d21223124c] | committer: Thomas 
Guillem

libvlc: add "auto" deinterlace-mode

Signed-off-by: Thomas Guillem 

> http://git.videolan.org/gitweb.cgi/vlc.git/?a=commit;h=174840ba85945431cfe55955671508d21223124c
---

 lib/video.c | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

diff --git a/lib/video.c b/lib/video.c
index f4e8fe22e1..536555c436 100644
--- a/lib/video.c
+++ b/lib/video.c
@@ -604,7 +604,8 @@ void libvlc_video_set_deinterlace( libvlc_media_player_t 
*p_mi,
  && strcmp (psz_mode, "discard")  && strcmp (psz_mode, "linear")
  && strcmp (psz_mode, "mean") && strcmp (psz_mode, "x")
  && strcmp (psz_mode, "yadif")&& strcmp (psz_mode, "yadif2x")
- && strcmp (psz_mode, "phosphor") && strcmp (psz_mode, "ivtc"))
+ && strcmp (psz_mode, "phosphor") && strcmp (psz_mode, "ivtc")
+ && strcmp (psz_mode, "auto"))
 return;
 
 if (*psz_mode)

___
vlc-commits mailing list
vlc-commits@videolan.org
https://mailman.videolan.org/listinfo/vlc-commits


[vlc-commits] libvlc: change set_deinterlace function

2018-05-09 Thread Luis Fernandes
vlc | branch: master | Luis Fernandes  | Sat May  5 17:34:14 
2018 +0100| [4dc621ab66545b99f84f2af7dd8fc951c8c6d4c2] | committer: Thomas 
Guillem

libvlc: change set_deinterlace function

Users will be able to change the deinterlace mode without forcing it.

Signed-off-by: Thomas Guillem 

> http://git.videolan.org/gitweb.cgi/vlc.git/?a=commit;h=4dc621ab66545b99f84f2af7dd8fc951c8c6d4c2
---

 include/vlc/libvlc_media_player.h |  7 +--
 lib/video.c   | 26 --
 2 files changed, 17 insertions(+), 16 deletions(-)

diff --git a/include/vlc/libvlc_media_player.h 
b/include/vlc/libvlc_media_player.h
index 7348728d9e..9ef1ddec24 100644
--- a/include/vlc/libvlc_media_player.h
+++ b/include/vlc/libvlc_media_player.h
@@ -1406,10 +1406,13 @@ int libvlc_video_take_snapshot( libvlc_media_player_t 
*p_mi, unsigned num,
  * Enable or disable deinterlace filter
  *
  * \param p_mi libvlc media player
- * \param psz_mode type of deinterlace filter, NULL to disable
+ * \param deinterlace state -1: auto (default), 0: disabled, 1: enabled
+ * \param psz_mode type of deinterlace filter, NULL for current/default filter
+ * \version LibVLC 4.0.0 and later
  */
 LIBVLC_API void libvlc_video_set_deinterlace( libvlc_media_player_t *p_mi,
-  const char *psz_mode );
+  int deinterlace,
+  const char *psz_mode );
 
 /**
  * Get an integer marquee option value
diff --git a/lib/video.c b/lib/video.c
index 536555c436..53b5de49db 100644
--- a/lib/video.c
+++ b/lib/video.c
@@ -592,13 +592,17 @@ end:
 }
 
 /**
- * libvlc_video_set_deinterlace : enable deinterlace
+ * libvlc_video_set_deinterlace : enable/disable/auto deinterlace and filter
  */
-void libvlc_video_set_deinterlace( libvlc_media_player_t *p_mi,
+void libvlc_video_set_deinterlace( libvlc_media_player_t *p_mi, int 
deinterlace,
const char *psz_mode )
 {
+if (deinterlace != 0 && deinterlace != 1)
+deinterlace = -1;
+
 if (psz_mode == NULL)
 psz_mode = "";
+
 if (*psz_mode
  && strcmp (psz_mode, "blend")&& strcmp (psz_mode, "bob")
  && strcmp (psz_mode, "discard")  && strcmp (psz_mode, "linear")
@@ -608,13 +612,10 @@ void libvlc_video_set_deinterlace( libvlc_media_player_t 
*p_mi,
  && strcmp (psz_mode, "auto"))
 return;
 
-if (*psz_mode)
-{
+if (*psz_mode && deinterlace != 0)
 var_SetString (p_mi, "deinterlace-mode", psz_mode);
-var_SetInteger (p_mi, "deinterlace", 1);
-}
-else
-var_SetInteger (p_mi, "deinterlace", 0);
+
+var_SetInteger (p_mi, "deinterlace", deinterlace);
 
 size_t n;
 vout_thread_t **pp_vouts = GetVouts (p_mi, );
@@ -622,13 +623,10 @@ void libvlc_video_set_deinterlace( libvlc_media_player_t 
*p_mi,
 {
 vout_thread_t *p_vout = pp_vouts[i];
 
-if (*psz_mode)
-{
+if (*psz_mode && deinterlace != 0)
 var_SetString (p_vout, "deinterlace-mode", psz_mode);
-var_SetInteger (p_vout, "deinterlace", 1);
-}
-else
-var_SetInteger (p_vout, "deinterlace", 0);
+
+var_SetInteger (p_vout, "deinterlace", deinterlace);
 vlc_object_release (p_vout);
 }
 free (pp_vouts);

___
vlc-commits mailing list
vlc-commits@videolan.org
https://mailman.videolan.org/listinfo/vlc-commits
--- a/vlcpp/MediaPlayer.hpp
+++ b/vlcpp/MediaPlayer.hpp
@@ -65,6 +65,15 @@ private:
 VideoCleanup,
 };
 public:
+#if LIBVLC_VERSION_INT >= LIBVLC_VERSION(4, 0, 0, 0)
+enum class DeinterlaceState : char
+{
+Auto = -1,
+Disabled =  0,
+Enabled  =  1
+};
+#endif
+
 /**
  * Check if 2 MediaPlayer objects contain the same libvlc_media_player_t.
  * \param another another MediaPlayer
@@ -1500,13 +1509,27 @@ public:
 /**
  * Enable or disable deinterlace filter
  *
  * \param psz_mode  type of deinterlace filter, empty string to disable
  */
+#if LIBVLC_VERSION_INT >= LIBVLC_VERSION(4, 0, 0, 0)
+void setDeinterlace(DeinterlaceState state, const std::string& mode)
+{
+libvlc_video_set_deinterlace(*this, static_cast( state ),
+ mode.empty() ? NULL : mode.c_str());
+}
+#else
 void setDeinterlace(const std::string& mode)
 {
 libvlc_video_set_deinterlace(*this,
  mode.empty() ? NULL : mode.c_str());
 }
+#endif
 
 /**
  * Get an integer marquee option value



View it on GitLab: 
https://code.videolan.org/videolan/libvlcpp/commit/28e2c7a668e740471c80eb3e7d66162aeffee4cf

---
View it on GitLab: 
https://code.videolan.org/videolan/libvlcpp/commit/28e2c7a668e740471c80eb3e7d66162aeffee4cf
You're receiving this email because of your account on code.videolan.org.
___
vlc-commits mailing list
vlc-commits@videolan.org
https://mailman.videolan.org/listinfo/vlc-commits


[vlc-commits] share: vlc.desktop.in: Add more translations

2018-05-09 Thread mtrz
vlc | branch: master | mtrz  | Mon May  7 01:37:48 2018 
+0200| [8d57d8dec842ed7b8110b8e0e290b8a69efb0691] | committer: Hugo 
Beauzée-Luyssen

share: vlc.desktop.in: Add more translations

Signed-off-by: Hugo Beauzée-Luyssen 

> http://git.videolan.org/gitweb.cgi/vlc.git/?a=commit;h=8d57d8dec842ed7b8110b8e0e290b8a69efb0691
---

 share/vlc.desktop.in | 51 ---
 1 file changed, 40 insertions(+), 11 deletions(-)
@@ -1500,13 +1509,27 @@ public:
  * Enable or disable deinterlace filter
  *
- * \param psz_mode  type of deinterlace filter, empty string to disable
+ * \version{2.x}
+ * \version{3.x}
+ * \param psz_mode  type of deinterlace filter, empty string to disable.
+ * \version{4.x}
+ * \param state The required deinterlacing state.
+ * \param mode  The deinterlace mode, or empty string for the current
+ *  or default filter.
  */
